@@ -2,10 +2,9 @@
 
 from typing import Any, Dict, Optional
 
-from baretypes import Info, Scope, WebSocket
-import graphene
-import graphql
-from graphql.subscription.map_async_iterator import MapAsyncIterator
+from bareasgi import WebSocketRequest
+from graphene import Schema
+from graphql import ExecutionResult, MapAsyncIterator
 
 from ..websocket_instance import GraphQLWebSocketHandlerInstanceBase
 
@@ -15,13 +14,12 @@ class GrapheneWebSocketHandlerInstance(GraphQLWebSocketHandlerInstanceBase):
 
     def __init__(
             self,
-            schema: graphene.Schema,
-            web_socket: WebSocket,
-            scope: Scope,
-            info: Info
+            schema: Schema,
+            request: WebSocketRequest
     ) -> None:
-        super().__init__(web_socket, scope, info)
+        super().__init__(request.web_socket)
         self.schema = schema
+        self.request = request
 
     async def subscribe(
             self,
@@ -33,7 +31,7 @@ class GrapheneWebSocketHandlerInstance(GraphQLWebSocketHandlerInstanceBase):
             query,
             variable_values=variables,
             operation_name=operation_name,
-            context_value={'scope': self.scope, 'info': self.info}
+            context_value=self.request
         )
 
     async def query(
@@ -41,10 +39,10 @@ class GrapheneWebSocketHandlerInstance(GraphQLWebSocketHandlerInstanceBase):
             query: str,
             variables: Optional[Dict[str, Any]],
             operation_name: Optional[str]
-    ) -> graphql.ExecutionResult:
+    ) -> ExecutionResult:
         return await self.schema.execute_async(
             source=query,
             variable_values=variables,
             operation_name=operation_name,
-            context_value={'scope': self.scope, 'info': self.info}
+            context_value=self.request
         )
