@@ -1,4 +1,4 @@
-"""bareASGI graphql-next"""
+"""bareASGI graphql support"""
 
 from .controller import GraphQLController
 from .helpers import add_graphql_next
